#
# spec file for package ghc-retry
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%global pkg_name retry

%bcond_with tests

Name:           ghc-retry
Version:        0.7.4
Release:        2.4
Summary:        Retry combinators for monadic actions that may fail
Group:          System/Libraries

License:        BSD-3-Clause
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  ghc-data-default-class-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-time-devel
%endif
# End cabal-rpm deps

%description
This package exposes combinators that can wrap arbitrary monadic actions.
They run the action and potentially retry running it with some configurable
delay for a configurable number of times. The purpose is to make it easier to
work with IO and especially network IO actions that often experience temporary
failure and warrant retrying of the original action. For example, a database
query may time out for a while, in which case we should hang back for a bit and
retry the query instead of simply raising an exception.


%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       %{name} = %{version}-%{release}

%description devel
This package provides the Haskell %{pkg_name} library development files.


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%check
%if %{with tests}
%cabal test
%endif


%post devel
%ghc_pkg_recache


%postun devel
%ghc_pkg_recache


%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE


%files devel -f %{name}-devel.files
%defattr(-,root,root,-)


%changelog
* Thu Jun  2 2016 mimi.vx@gmail.com
- update to 0.7.4
  * Widen transformers dependency
* Mon May 30 2016 mimi.vx@gmail.com
- update to 0.7.3
  * Widen ghc-prim dependency for GHC 8
* Wed May  4 2016 mimi.vx@gmail.com
- update to 0.7.2
  * Fix premature integer overflow
* Fri Jan 15 2016 mimi.vx@gmail.com
- update to 0.7.1
  * Various documentation updates.
  * Add stepping combinator for manual retries.
  * Add applyPolicy and applyAndDelay
  * Add Read instance for RetryStatus
  * Fix logic bug in rsPreviousDelay in first retry
* Wed Dec 23 2015 mimi.vx@gmail.com
- update to 0.7.0.1
  * RetryPolicy has become RetryPolicyM, allowing for policy logic to consult the
  monad context.
  * RetryPolicyM now takes a RetryStatus value. Use the function rsIterNum to
  preserve existing behavior of RetryPolicy only receiving the number.
  * The monadic action now gets the RetryStatus on each try. Use const if you
  don't need it.
  * recoverAll explicitly does not handle the standard async exceptions. Users are
  encouraged to do the same when using recovering, as catching async exceptions
  can be hazardous.
  * We no longer re-export (<>) from Monoid.
  * Utility functions simulatePolicy and simulatePolicyPP have been added which help
  predict how a policy will behave on each iteration.
* Thu Nov 19 2015 mimi.vx@gmail.com
- initial commit
